.. image:: https://img.shields.io/pypi/v/jaraco.home.svg
   :target: https://pypi.org/project/jaraco.home

.. image:: https://img.shields.io/pypi/pyversions/jaraco.home.svg

.. image:: https://img.shields.io/travis/jaraco/jaraco.home/master.svg
   :target: https://travis-ci.org/jaraco/jaraco.home

.. .. image:: https://img.shields.io/appveyor/ci/jaraco/skeleton/master.svg
..    :target: https://ci.appveyor.com/project/jaraco/skeleton/branch/master

.. image:: https://readthedocs.org/projects/jaracohome/badge/?version=latest
   :target: https://jaracohome.readthedocs.io/en/latest/?badge=latest
